@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::DumpHistory;
-BEGIN {
-  $Devel::REPL::Plugin::DumpHistory::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::DumpHistory::VERSION = '1.003026';
+# ABSTRACT: Plugin for Devel::REPL to save or print the history
+
+our $VERSION = '1.003029';
+
 use Devel::REPL::Plugin;
 use namespace::autoclean;
 
@@ -46,14 +46,17 @@ sub print_history {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::REPL::Plugin::DumpHistory - Plugin for Devel::REPL to save or print
-the history.
+Devel::REPL::Plugin::DumpHistory - Plugin for Devel::REPL to save or print the history
 
 =head1 VERSION
 
-version 1.003026
+version 1.003029
 
 =head1 SYNOPSIS
 
@@ -75,6 +78,14 @@ file given.
 
 C<Devel::REPL>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 mgrimes, E<lt>mgrimes at cpan dot org<gt>
