@@ -1,10 +1,10 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::FindVariable;
-BEGIN {
-  $Devel::REPL::Plugin::FindVariable::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::FindVariable::VERSION = '1.003026';
+# ABSTRACT: Finds variables by name
+
+our $VERSION = '1.003029';
+
 use Devel::REPL::Plugin;
 use namespace::autoclean;
 
@@ -37,16 +37,35 @@ sub find_variable {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::REPL::Plugin::FindVariable - Finds variables by name
 
 =head1 VERSION
 
-version 1.003026
+version 1.003029
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
 
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
