@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::LexEnv;
 # ABSTRACT: Provide a lexical environment for the REPL
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003029';
 
 use Devel::REPL::Plugin;
 use namespace::autoclean;
@@ -78,7 +78,7 @@ Devel::REPL::Plugin::LexEnv - Provide a lexical environment for the REPL
 
 =head1 VERSION
 
-version 1.003027
+version 1.003029
 
 =head1 SYNOPSIS
 
@@ -99,11 +99,19 @@ version 1.003027
  # after you run re.pl:
  $ warn $s->resultset('User')->first->first_name # <-- note that $s works
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2007 by Matt S Trout - mst (at) shadowcatsystems.co.uk (L<http://www.shadowcatsystems.co.uk/>).
 
