@@ -1,12 +1,9 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin::OutputCache;
-BEGIN {
-  $Devel::REPL::Plugin::OutputCache::AUTHORITY = 'cpan:PHAYLON';
-}
-{
-  $Devel::REPL::Plugin::OutputCache::VERSION = '1.003024';
-}
+# ABSTRACT: Remember past results, _ is most recent
+
+our $VERSION = '1.003029';
 
 use Devel::REPL::Plugin;
 use namespace::autoclean;
@@ -58,9 +55,17 @@ around 'eval' => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Devel::REPL::Plugin::OutputCache - remember past results, _ is most recent
+Devel::REPL::Plugin::OutputCache - Remember past results, _ is most recent
+
+=head1 VERSION
+
+version 1.003029
 
 =head1 SYNOPSIS
 
@@ -81,7 +86,7 @@ your result instead of having to type it in all at once, or store it in
 intermediate variables. C<OutputCache> also provides
 C<< $_REPL->output_cache >>, an array reference of all results in this session.
 
-Devel::REPL already has a similar plugin, L<Devel::REPL::Plugin::History>.
+L<Devel::REPL> already has a similar plugin, L<Devel::REPL::Plugin::History>.
 There are some key differences though:
 
 =over 4
@@ -109,13 +114,21 @@ does the parsing -- no surprises.
 
 The C<_> sub is shared across all packages. This means that if a module is
 using the C<_> sub, then there is a conflict and you should not use this
-plugin. For example, L<Jifty> uses the C<_> sub for localization. Jifty is the
+plugin. For example, L<Jifty> uses the C<_> sub for localization. L<Jifty> is the
 only known user.
 
 =head1 SEE ALSO
 
 C<Devel::REPL>, C<Devel::REPL::Plugin::History>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
